# Changelog — repro-tarfile

## v0.2.1 (2025-10-05)

- Added Python 3.14 to supported versions.

## v0.2.0 (2025-03-22)

- Added support for Python 3.13. ([PR #9](https://github.com/drivendataorg/repro-tarfile/pull/9))
- Added support for type checking per [PEP 561 specification](https://typing.python.org/en/latest/spec/distributing.html#packaging-typed-libraries). Types are declared with `.pyi` stubs file. ([PR #10](https://github.com/drivendataorg/repro-tarfile/pull/10))

## v0.1.0 (2024-02-02)

Initial release! 🎉
